@@ -1,7 +1,7 @@
 
 # Imports
-from ..utils.io import *
-from ..utils.print import *
+import os
+import stouputils as stp
 from PIL import Image
 
 def main(config: dict):
@@ -11,11 +11,11 @@ def main(config: dict):
 	# img.save(f"{config['build_resource_pack']}/assets/{config['namespace']}/textures/item/test.png")
 
 	# Get all textures in the resource pack folder
-	wrongs: list[str] = []
+	wrongs: list[tuple[str, int, int]] = []
 	for root, _, files in os.walk(f"{config['build_resource_pack']}/assets/{config['namespace']}/textures"):
 		for file in files:
 			if file.endswith(".png") and ("block" in root or "item" in root):
-				file_path: str = clean_path(f"{root}/{file}")
+				file_path: str = stp.clean_path(f"{root}/{file}")
 
 				# Check if the texture is in power of 2 resolution
 				image: Image.Image = Image.open(file_path)
@@ -31,5 +31,5 @@ def main(config: dict):
 		text: str = f"The following textures are not in power of 2 resolution (2x2, 4x4, 8x8, 16x16, ...):\n"
 		for file_path, width, height in wrongs:
 			text += f"- {file_path}\t({width}x{height})\n"
-		warning(text)
+		stp.warning(text)
 
